@@ -21,49 +21,42 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-class Audio:
-    """This object shows a waist.
+from typing import TYPE_CHECKING
+
+from .file import File
+if TYPE_CHECKING:
+    from bale import Bot
+
+
+class Audio(File):
+    """This object shows a Audio.
 
     Attributes
     ----------
         file_id: str
-            Audio ID
+            Identifier for this file, which can be used to download or reuse the file.
         duration: int
-            Audio duration
+            Duration of the audio in seconds as defined by sender.
         file_size: int
-            Audio Size.
+            File size in bytes.
         mime_type: Optional[:class:`str`]
-            Audio Mime type.
+            MIME type of the file as defined by sender.
         title: Optional[:class:`str`]
-            Audio Title.
+            Title of the audio as defined by sender or by audio tags.
     """
-    __slots__ = (
-        "file_id",
+    __FILE_TYPE__ = "AUDIO"
+    __slots__ = File.__slots__ + (
         "duration",
-        "title",
-        "file_size",
-        "mime_type",
-        "bot"
+        "title"
     )
 
-    def __init__(self, file_id: str, duration: int, file_size: int = None, mime_type: str = None, title: str = None):
-        self.file_id = file_id
-        self.duration = duration
+    def __init__(self, file_id: str, duration: int = None, file_size: int = None, bot: "Bot" = None, mime_type: str = None, title: str = None):
+        super().__init__(self.__FILE_TYPE__, file_id, file_size, mime_type, bot, duration=duration, title=title)
 
+        self.duration = duration
         self.title = title
-        self.file_size = file_size
-        self.mime_type = mime_type
 
     @classmethod
-    def from_dict(cls, data):
+    def from_dict(cls, data, bot: "Bot"):
         return cls(file_id=data["file_id"], duration=data["duration"], file_size=data["file_size"], title=data["title"],
-                   mime_type=data["mime_type"])
-
-    def to_dict(self):
-        data = {"file_id": self.file_id if self.file_id is not None else None,
-                "duration": self.duration if self.duration is not None else None,
-                "title": self.title if self.title is not None else None,
-                "file_size": self.file_size if self.file_size is not None else None,
-                "mime_type": self.mime_type if self.mime_type is not None else None}
-
-        return data
\ No newline at end of file
+                   mime_type=data["mime_type"], bot=bot)
\ No newline at end of file
