@@ -26,8 +26,8 @@ import asyncio
 from typing import Callable, Dict, Tuple, List, Optional
 from builtins import enumerate, reversed
 from .error import NotFound, InvalidToken
-from bale import (Message, Update, User, Components, RemoveComponents, Chat, Price, ChatMember, HTTPClient, Updater,
-                  Photo, Document, Location, ContactMessage, Video)
+from bale import (Message, Update, User, Components, RemoveMenuKeyboard, Chat, Price, ChatMember, HTTPClient, Updater,
+                  Photo, Document, Location, ContactMessage, Video, Audio)
 
 __all__ = (
     "Bot"
@@ -55,7 +55,6 @@ class Bot:
         token: str 
             Bot Token
         updater: Optional[:class:`bale.Updater`]
-        base_url: Optional[:class:`str`]
 
     .. note::
         When you create bot and run for first-step, use :meth:`bale.Bot.delete_webhook` method in `on_ready` event.
@@ -77,7 +76,7 @@ class Bot:
             raise InvalidToken("token must be type of the str")
         self.loop = _loop
         self.token = token
-        self.http: HTTPClient = HTTPClient(self.loop, token, kwargs.get("base_url"))
+        self.http: HTTPClient = HTTPClient(self.loop, token)
         self._user = None
         self.events: Dict[str, List[Callable]] = {}
         self.listeners: Dict[str, List[Tuple[asyncio.Future, Callable[..., bool]]]] = {}
@@ -167,7 +166,7 @@ class Bot:
     def call_to_run_event(self, core, event_name, *args, **kwargs):
         task = self.run_event(core, event_name, *args, **kwargs)
         self.loop: asyncio.AbstractEventLoop
-        return self.loop.create_task(task, name=event_name)
+        return self.loop.create_task(task, name=f"python-bale-bot: {event_name}")
 
     def dispatch(self, event_name, /, *args, **kwargs):
         method = "on_" + event_name
@@ -213,7 +212,7 @@ class Bot:
 
         Returns
         -------
-            :class:`Bale.User` :
+            :class:`bale.User` :
                 Bot User information.
         Raises
         ------
@@ -241,7 +240,7 @@ class Bot:
         return response.result or False
 
     async def send_message(self, chat_id: str | int, text: str, *,
-                           components: Optional["Components" | "RemoveComponents"] = None,
+                           components: Optional["Components" | "RemoveMenuKeyboard"] = None,
                            reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send text messages.
 
@@ -274,7 +273,7 @@ class Bot:
             )
 
         if components:
-            if not isinstance(components, (Components, RemoveComponents)):
+            if not isinstance(components, (Components, RemoveMenuKeyboard)):
                 raise TypeError(
                     "components param must be type of Components or RemoveComponents"
                 )
@@ -299,7 +298,7 @@ class Bot:
             from_chat_id: :class:`str` | :class:`int`
                 the chat where the original message was sent (or channel username in the format @channelusername).
             message_id: :class:`int` | :class:`str`
-                Message in the chat specified in :param:`from_chat_id`.
+                Message in the chat specified in ``from_chat_id``.
         Returns
         -------
             :class:`bale.Message`
@@ -341,7 +340,7 @@ class Bot:
         chat_id: :class:`str` | :class:`int`
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
         document: :class:`bytes` | :class:`str` | :class:`bale.Document`
-            File to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Telegram to get a file from the Internet, or upload a new one.
+            File to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
         caption: Optional[:class:`str`]
             Document caption.
         reply_to_message_id: Optional[:class:`str` | :class:`int`]
@@ -392,7 +391,7 @@ class Bot:
             chat_id: :class:`str` | :class:`int`
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
             photo: :class:`bytes` | :class:`str` | :class:`bale.Photo`
-                Photo to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Telegram to get a file from the Internet, or upload a new one.
+                Photo to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
             caption: Optional[:class:`str`]
                 Photo caption.
             reply_to_message_id: Optional[:class:`str` | :class:`int`]
@@ -439,6 +438,62 @@ class Bot:
                                               reply_to_message_id=reply_to_message_id)
         return Message.from_dict(data=response.result, bot=self)
 
+    async def send_audio(self, chat_id: str | int, audio: bytes | str | "Audio", *, caption: Optional[str] = None,
+                         reply_to_message_id: Optional[str | int] = None) -> "Message":
+        """This service is used to send Audio.
+
+        Parameters
+        ----------
+            chat_id: :class:`str` | :class:`int`
+                Unique identifier for the target chat or username of the target channel (in the format @channelusername).
+            audio: :class:`bytes` | :class:`str` | :class:`bale.Audio`
+                Audio file to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
+            caption: Optional[:class:`str`]
+                Audio caption.
+            reply_to_message_id: Optional[:class:`str` | :class:`int`]
+                Additional interface options. An object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
+
+        Returns
+        --------
+            :class:`bale.Message`
+                The Message.
+
+        Raises
+        ------
+            NotFound
+                Invalid Chat ID.
+            Forbidden
+                You do not have permission to Send Audio to chat.
+            APIError
+                Send Audio Failed.
+        """
+        if not isinstance(chat_id, (str, int)):
+            raise TypeError(
+                "chat_id param must be type of str or int"
+            )
+
+        if not isinstance(audio, (bytes, str, Audio)):
+            raise TypeError(
+                "audio param must be type of bytes, str or Audio"
+            )
+
+        if isinstance(audio, Audio):
+            audio = audio.file_id
+
+        if reply_to_message_id and not isinstance(reply_to_message_id, (str, int)):
+            raise TypeError(
+                "reply_to_message_id param must be type of str or int"
+            )
+
+        if caption and not isinstance(caption, str):
+            raise TypeError(
+                "caption param must be type of str"
+            )
+
+        response = await self.http.send_audio(str(chat_id), audio, caption=caption,
+                                              reply_to_message_id=reply_to_message_id)
+        return Message.from_dict(data=response.result, bot=self)
+
     async def send_video(self, chat_id: str | int, video: bytes | str | "Photo", *, caption: Optional[str] = None,
                          reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send Video.
@@ -448,7 +503,7 @@ class Bot:
             chat_id: :class:`str` | :class:`int`
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
             video: :class:`bytes` | :class:`str` | :class:`bale.Photo`
-                Video to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Telegram to get a file from the Internet, or upload a new one.
+                Video to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
             caption: Optional[:class:`str`]
                 Video caption.
             reply_to_message_id: Optional[:class:`str` | :class:`int`]
@@ -500,10 +555,10 @@ class Bot:
 
         Parameters
         ----------
-        chat_id: :class:`str` | :class:`int`
+            chat_id: :class:`str` | :class:`int`
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
-        location: :class:`bale.Location`
-            The Location.
+            location: :class:`bale.Location`
+                The Location.
 
         Returns
         --------
@@ -537,10 +592,10 @@ class Bot:
 
         Parameters
         ----------
-        chat_id: :class:`str` | :class:`int`
-                Unique identifier for the target chat or username of the target channel (in the format @channelusername).
-        contact: :class:`bale.ContactMessage`
-            The Contact.
+            chat_id: :class:`str` | :class:`int`
+                    Unique identifier for the target chat or username of the target channel (in the format @channelusername).
+            contact: :class:`bale.ContactMessage`
+                The Contact.
 
         Returns
         --------
@@ -580,28 +635,28 @@ class Bot:
 
         Parameters
         ----------
-        chat_id: :class:`str` | :class:`int`
-                Unique identifier for the target chat or username of the target channel (in the format @channelusername).
-        title: str
-            Product name. 1- 32 characters.
-        description: str
-            Product description. 1- 255 characters.
-        provider_token: str
-            You can use 3 methods to receive money: 1.Card number 2. Port number and acceptor number 3. Wallet number "Bale"
-        prices: List[:class:`bale.Price`]
-            A list of prices.
-        photo_url: Optional[:class:`str`]
-            URL of the product photo for the invoice. Can be a photo of the goods or a marketing image for a service. People like it better when they see what they are paying for.
-        need_name: Optional[bool]
-            Pass True, if you require the user’s full name to complete the order.
-        need_phone_number: Optional[bool]
-            Pass True, if you require the user’s phone number to complete the order.
-        need_email: Optional[bool]
-            Pass True, if you require the user’s email to complete the order.
-        need_shipping_address: Optional[bool]
-            Pass True, if you require the user’s shipping address to complete the order.
-        is_flexible: Optional[bool]
-            Pass True, if the final price depends on the shipping method.
+            chat_id: :class:`str` | :class:`int`
+                    Unique identifier for the target chat or username of the target channel (in the format @channelusername).
+            title: str
+                Product name. 1- 32 characters.
+            description: str
+                Product description. 1- 255 characters.
+            provider_token: str
+                You can use 3 methods to receive money: 1.Card number 2. Port number and acceptor number 3. Wallet number "Bale"
+            prices: List[:class:`bale.Price`]
+                A list of prices.
+            photo_url: Optional[:class:`str`]
+                URL of the product photo for the invoice. Can be a photo of the goods or a marketing image for a service. People like it better when they see what they are paying for.
+            need_name: Optional[bool]
+                Pass True, if you require the user’s full name to complete the order.
+            need_phone_number: Optional[bool]
+                Pass True, if you require the user’s phone number to complete the order.
+            need_email: Optional[bool]
+                Pass True, if you require the user’s email to complete the order.
+            need_shipping_address: Optional[bool]
+                Pass True, if you require the user’s shipping address to complete the order.
+            is_flexible: Optional[bool]
+                Pass True, if the final price depends on the shipping method.
 
         Returns
         -------
@@ -621,32 +676,47 @@ class Bot:
                 "chat param must be type of str or int"
             )
 
-        if not isinstance(photo_url, str):
+        if not isinstance(title, str):
+            raise TypeError(
+                "title param must be type of str"
+            )
+
+        if not isinstance(provider_token, str):
+            raise TypeError(
+                "provider_token param must be type of str"
+            )
+
+        if not isinstance(prices, list):
+            raise TypeError(
+                "prices must param must be type of list"
+            )
+
+        if photo_url and not isinstance(photo_url, str):
             raise TypeError(
                 "photo_url param must be type of str"
             )
 
-        if not isinstance(need_name, bool):
+        if need_name is not None and not isinstance(need_name, bool):
             raise TypeError(
                 "need_name param must be type of boolean"
             )
 
-        if not isinstance(need_phone_number, bool):
+        if need_phone_number is not None and not isinstance(need_phone_number, bool):
             raise TypeError(
                 "need_phone_number param must be type of boolean"
             )
 
-        if not isinstance(need_email, bool):
+        if need_email is not None and not isinstance(need_email, bool):
             raise TypeError(
                 "need_email param must be type of boolean"
             )
 
-        if not isinstance(need_shipping_address, bool):
+        if need_shipping_address is not None and not isinstance(need_shipping_address, bool):
             raise TypeError(
                 "need_shipping_address param must be type of boolean"
             )
 
-        if not isinstance(is_flexible, bool):
+        if is_flexible is not None and not isinstance(is_flexible, bool):
             raise TypeError(
                 "is_flexible param must be type of boolean"
             )
@@ -658,7 +728,7 @@ class Bot:
         return Message.from_dict(data=response.result, bot=self)
 
     async def edit_message(self, chat_id: str | int, message_id: str | int, text: str, *,
-                           components: Optional["Components" | "RemoveComponents"] = None) -> "Message":
+                           components: Optional["Components" | "RemoveMenuKeyboard"] = None) -> "Message":
         """You can use this service to edit text messages that you have already sent through the arm.
 
         Parameters
@@ -690,7 +760,7 @@ class Bot:
                 "message_id param must be type of str or int"
             )
 
-        if components and not isinstance(components, (Components, RemoveComponents)):
+        if components and not isinstance(components, (Components, RemoveMenuKeyboard)):
             raise TypeError(
                 "components param must be type of Components or RemoveComponents"
             )
@@ -1028,8 +1098,8 @@ class Bot:
             )
 
         response = await self.http.get_updates(offset, limit)
-        return [Update.from_dict(data=update_payload, bot=self) for update_payload in response.result or list()
-                if not offset or (offset and update_payload.get("update_id") > offset)]
+        return [Update.from_dict(data=update_payload, bot=self) for update_payload in response.result
+                if not offset or (offset and update_payload.get("update_id") > offset)] if response.result else None
 
     async def connect(self, sleep_after_every_get_updates):
         self._user = await self.get_bot()
@@ -1046,3 +1116,5 @@ class Bot:
             asyncio.run(main())
         except KeyboardInterrupt:  # Control-C
             pass
+        except SystemExit:
+            pass
