@@ -25,7 +25,7 @@ from __future__ import annotations
 from bale import User
 from typing import TYPE_CHECKING, Optional, List
 if TYPE_CHECKING:
-    from bale import Bot, Message, User, Photo, Document, Components, RemoveComponents, Price, Location, ContactMessage, Video
+    from bale import Bot, Message, User, Photo, Document, Components, RemoveMenuKeyboard, Price, Location, ContactMessage, Video, Audio
 
 
 __all__ = (
@@ -142,7 +142,7 @@ class Chat:
         """Optional[:class:`str`]"""
         return ("@" + self.username) if self.username else None
 
-    async def send(self, text: str, components: Optional["Components" | "RemoveComponents"] = None):
+    async def send(self, text: str, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_message`.
         """
@@ -150,7 +150,7 @@ class Chat:
 
     async def send_document(self, document: bytes | str | "Document", *, caption: Optional[str] = None):
         """
-        For the documentation of the arguments, please see :meth:`bale.Bot.send_photo`.
+        For the documentation of the arguments, please see :meth:`bale.Bot.send_document`.
         """
         return await self.bot.send_document(self.chat_id, document, caption=caption)
 
@@ -160,11 +160,17 @@ class Chat:
         """
         return await self.bot.send_photo(self.chat_id, photo, caption=caption)
 
-    async def send_video(self, photo: bytes | str | "Video", *, caption: Optional[str] = None):
+    async def send_video(self, video: bytes | str | "Video", *, caption: Optional[str] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_video`.
         """
-        return await self.bot.send_video(self.chat_id, photo, caption=caption)
+        return await self.bot.send_video(self.chat_id, video, caption=caption)
+
+    async def send_audio(self, audio: bytes | str | "Audio", *, caption: Optional[str] = None):
+        """
+        For the documentation of the arguments, please see :meth:`bale.Bot.send_audio`.
+        """
+        return await self.bot.send_audio(self.chat_id, audio, caption=caption)
 
     async def send_location(self, location: "Location"):
         """
@@ -196,7 +202,7 @@ class Chat:
 
     async def add_user(self, user: "User"):
         """
-        For the documentation of the arguments, please see :meth:`bale.Bot.invite_to_chat`.
+        For the documentation of the arguments, please see :meth:`bale.Bot.invite_user`.
         """
         await self.bot.invite_user(self.chat_id, user.chat_id)
 
@@ -257,8 +263,7 @@ class Chat:
         return data
 
     def __str__(self):
-        return (str(self.username) + "#" + str(self.chat_id) if self.username else str(self.first_name) + " " + str(
-            self.last_name))
+        return str(self.first_name) + str(self.last_name)
 
     def __eq__(self, other):
         return isinstance(other, Chat) and self.chat_id == other.chat_id
