@@ -21,16 +21,20 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from bale import (Permissions, User)
+from __future__ import annotations
+from typing import TYPE_CHECKING
+if TYPE_CHECKING:
+    from bale import Bot
+from bale import Permissions, User
 
 __all__ = (
-    "MemberRole",
+    "ChatMemberStatus",
     "ChatMember"
 )
 
 
-class MemberRole:
-    """This object shows member's role in chat.
+class ChatMemberStatus:
+    """This object shows member's status in chat.
 
     .. container:: operations
         .. describe:: x == y
@@ -40,32 +44,39 @@ class MemberRole:
     """
 
     OWNER = "creator"
-    CREATOR = OWNER
     ADMIN = "administrator"
-    __slots__ = ("_role", )
+    MEMBER = "member"
+    CREATOR = OWNER
+    __slots__ = ("_status",)
 
-    def __init__(self, _role: str):
-        self._role = _role
+    def __init__(self, _status: str):
+        self._status = _status
 
     @property
-    def role(self) -> str:
-        return self._role
+    def status(self) -> str:
+        """"""
+        return self._status
 
     def is_owner(self):
         """bool:
 			Return ``True`` if Member is chat creator"""
-        return self._role == self.OWNER
+        return self._status == self.OWNER
 
     def is_admin(self):
         """bool:
-			Return ``True`` if Member have admin role"""
-        return self._role == self.ADMIN
+			Return ``True`` if Member have admin status"""
+        return self._status == self.ADMIN
+
+    def is_member(self):
+        """bool:
+            Return ``True`` if Member haven't any status"""
+        return self._status == self.MEMBER
 
     def __repr__(self):
-        return f"<MemberRole role={self.role}>"
+        return f"<MemberRole role={self.status}>"
 
     def __eq__(self, other):
-        return self._role == other
+        return self._status == other
 
     def __ne__(self, other):
         return not self.__eq__(other)
@@ -76,29 +87,34 @@ class ChatMember:
 
     Attributes
     ----------
-        role: :class:`bale.MemberRole`
-            User Role
         user: :class:`bale.User`
-            User
-        permissions: :class:`bale.AdminPermissions`
-            User Permissions
+            Information about the user.
+        status: :class:`bale.ChatMemberStatus`
+            The member’s status in the chat.
+        permissions: :class:`bale.Permissions`
+            The member’s permissions in the chat.
     """
     __slots__ = (
-        "role", "_user", "permissions"
+        "chat_id", "status", "user", "permissions", "bot"
     )
 
-    def __init__(self, role: "MemberRole", user, permissions):
-        self.role = role
-        self._user = user
+    def __init__(self, chat_id: int, status: "ChatMemberStatus", user: "User", permissions: "Permissions", bot: "Bot"):
+        self.chat_id = chat_id
+        self.status = status
+        self.user = user
         self.permissions = permissions
+        self.bot = bot
 
-    @property
-    def user(self) -> "User":
-        return self._user
+    async def ban(self):
+        """
+        For the documentation of the arguments, please see :meth:`bale.Bot.ban_chat_member`.
+        """
+        return await self.bot.ban_chat_member(self.chat_id, self.user.user_id)
 
     @classmethod
-    def from_dict(cls, data: dict):
-        return cls(permissions=Permissions.from_dict(data), user=User.from_dict(data.get("user")), role=MemberRole(data.get("status")))
+    def from_dict(cls, chat_id: int, data: dict, bot: "Bot"):
+        return cls(chat_id=chat_id, permissions=Permissions.from_dict(data), user=User.from_dict(data.get("user")),
+                   status=ChatMemberStatus(data.get("status")), bot=bot)
 
     def __repr__(self):
-        return f"<ChatMember role={self.role} user={self._user} permissions={self.permissions}>"
+        return f"<ChatMember chat_id={self.chat_id} status={self.status} user={self.user} permissions={self.permissions}>"
