@@ -24,13 +24,13 @@ SOFTWARE.
 from __future__ import annotations
 
 from datetime import datetime
-from typing import TYPE_CHECKING, List, Optional
+from typing import TYPE_CHECKING, List, Optional, NoReturn
 
 if TYPE_CHECKING:
     from bale import Bot
 
-from bale import (Chat, User, Document, ContactMessage, Location, Photo, Invoice, Components, RemoveComponents, Price,
-                  Video)
+from bale import (Chat, User, Document, ContactMessage, Location, Photo, Invoice, Components, RemoveMenuKeyboard,
+                  Video, Audio, File)
 
 
 class Message:
@@ -41,7 +41,8 @@ class Message:
         message_id: str
             Unique message identifier inside this chat.
         from_user: Optional[:class:`bale.User`]
-            Sender of the message; empty for messages sent to channels. For backward compatibility, this will contain a fake sender user in non-channel chats, if the message was sent on behalf of a chat.
+            Sender of the message; empty for messages sent to channels. For backward compatibility, this will contain a
+            fake sender user in non-channel chats, if the message was sent on behalf of a chat.
         chat: :class:`bale.Chat`
             Conversation the message belongs to.
         date: :class:`datetime.datetime`
@@ -55,15 +56,21 @@ class Message:
         forward_from_chat: Optional[:class:`bale.Chat`]
             For messages forwarded from channels or from anonymous administrators, information about the original sender chat.
         reply_to_message: Optional[:class:`bale.Message`]
-            For replies, the original message. Note that the Message object in this field will not contain further reply_to_message fields even if it itself is a reply.
+            For replies, the original message. Note that the Message object in this field will not contain further
+            reply_to_message fields even if it itself is a reply.
         contact: Optional[:class:`bale.ContactMessage`]
             Message is a shared contact, information about the contact.
         location: Optional[:class:`bale.Location`]
             Message is a shared location, information about the location.
         document: Optional[:class:`bale.Document`]
             Message is a general file, information about the file.
+        video: Optional[:class:`bale.Video`]
+            Message is a video, information about the video.
+        audio: Optional[:class:`bale.Audio`]
+            Message is an audio, information about the Audio.
         new_chat_members: Optional[List[:class:`bale.User`]]
-            New members that were added to the group or supergroup and information about them (the bot itself may be one of these members). This list is empty if the message does not contain new chat members.
+            New members that were added to the group or supergroup and information about them (the bot itself may be
+            one of these members). This list is empty if the message does not contain new chat members.
         left_chat_member: Optional[:class:`bale.User`]
             A member was removed from the group, information about them (this member may be the bot itself).
         invoice: Optional[:class:`bale.Invoice`]
@@ -72,7 +79,7 @@ class Message:
     __slots__ = (
         "text", "caption", "from_user", "_author", "contact", "location", "chat", "message_id", "forward_from",
         "forward_from_chat", "forward_from_message_id", "date_code", "date",
-        "edit_date", "audio", "document", "photos", "voice", "location", "invoice", "new_chat_members",
+        "edit_date", "audio", "document", "video", "photos", "location", "invoice", "new_chat_members",
         "left_chat_member", "reply_to_message",
         "invoice", "bot"
     )
@@ -82,8 +89,9 @@ class Message:
                  forward_from_message_id: Optional[str] = None, from_user: Optional["User"] = None,
                  document: Optional["Document"] = None,
                  contact: Optional["ContactMessage"] = None, location: Optional["Location"] = None,
-                 chat: Optional["Chat"] = None, photos: Optional[List["Photo"]] = None,
-                 reply_to_message: Optional["Message"] = None, invoice: Optional["Invoice"] = None,
+                 chat: Optional["Chat"] = None, video: Optional["Video"] = None,
+                 photos: Optional[List["Photo"]] = None, reply_to_message: Optional["Message"] = None,
+                 invoice: Optional["Invoice"] = None, audio: Optional["Audio"] = None,
                  bot: 'Bot' = None, **options):
         self.message_id: str = message_id if message_id is not None else None
         self.date = date if date is not None else None
@@ -97,6 +105,8 @@ class Message:
         self.forward_from_chat: Chat | None = forward_from_chat if forward_from_chat is not None else None
         self.caption: str | None = caption if caption is not None else None
         self.document = document if document is not None else None
+        self.video = video if video is not None else None
+        self.audio = audio if audio is not None else None
         self.photos = photos if photos is not None else None
         self.contact: ContactMessage | None = contact if contact is not None else None
         self.location: Location | None = location if location is not None else None
@@ -111,37 +121,45 @@ class Message:
         return self.from_user
 
     @property
-    def content(self):
+    def attachment(self) -> Optional["File"]:
+        """Optional[:class:`bale.File`]: Represents the message attachment. ``None`` if the message don't have any attachments"""
+        attachment = self.video or self.photos or self.audio or self.document
+        if not attachment:
+            return
+
+        if isinstance(attachment, list):
+            attachment = attachment[0]
+
+        return attachment.base_file
+
+    @property
+    def content(self) -> Optional[str]:
+        """Optional[:class:`str`]: Represents the message content. ``None`` if the message don't have text or caption"""
         return self.caption or self.text
 
     @content.setter
-    def content(self, _value):
+    def content(self, _value: str) -> NoReturn:
         if not isinstance(_value, str):
             raise TypeError("content must be type of str")
+
         if self.caption:
             self.caption = _value
         elif self.text:
             self.text = _value
 
     @property
-    def chat_id(self):
-        if self.chat:
-            return self.chat.chat_id
-        return None
+    def chat_id(self) -> Optional[str | int]:
+        """:class:`str` | :class:`int`: Represents the Unique identifier of Conversation the message belongs to."""
+        return self.chat.chat_id
 
     @property
-    def reply_to_message_id(self):
-        if self.reply_to_message:
-            return self.reply_to_message.message_id
-        return None
+    def reply_to_message_id(self) -> Optional[str]:
+        """Optional[:class:`str`]: Represents the Unique identifier of Original message, if the message has been replied. ``None`` If the message is not replied"""
+        if not self.reply_to_message:
+            return
 
-    @reply_to_message_id.setter
-    def reply_to_message_id(self, _value):
-        if not isinstance(_value, int):
-            raise TypeError("_value must be type of int")
+        return self.reply_to_message.message_id
 
-        if self.reply_to_message:
-            self.reply_to_message.message_id = _value
 
     @classmethod
     def from_dict(cls, data: dict, bot):
@@ -167,8 +185,9 @@ class Message:
                    document=Document.from_dict(bot=bot, data=data.get("document")) if data.get("document") else None,
                    contact=ContactMessage.from_dict(data=data.get("contact")) if data.get("contact") else None,
                    location=Location.from_dict(data=data.get("location")) if data.get("location") else None,
-                   photos=[Photo.from_dict(data=photo_payload) for photo_payload in data.get("photo")] if data.get(
-                       "photo") else None,
+                   audio=Audio.from_dict(data=data.get("audio"), bot=bot) if data.get("audio") else None,
+                   photos=[Photo.from_dict(data=photo_payload, bot=bot) for photo_payload in data.get("photo")] if data.get(
+                       "photo") else None, video=Video.from_dict(data=data.get("video"), bot=bot) if data.get("video") else None,
                    invoice=Invoice.from_dict(data=data.get("invoice")) if data.get("invoice") else None, **options)
 
     def to_dict(self):
@@ -184,6 +203,10 @@ class Message:
             data["document"] = self.document.to_dict()
         if self.photos:
             data["photo"] = [photo.to_dict() for photo in self.photos]
+        if self.video:
+            data["video"] = self.video.to_dict()
+        if self.audio:
+            data["audio"] = self.audio.to_dict()
         if self.contact:
             data["contact"] = self.contact.to_dict()
         if self.location:
@@ -201,7 +224,7 @@ class Message:
 
         return data
 
-    async def reply(self, text: str, *, components: Optional[Components | RemoveComponents] = None):
+    async def reply(self, text: str, *, components: Optional[Components | RemoveMenuKeyboard] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_message`.
         """
@@ -235,20 +258,14 @@ class Message:
         return await self.bot.send_video(self.chat_id, video, caption=caption,
                                          reply_to_message_id=self.message_id if not self.chat.type.is_group_chat() else None)
 
-    async def reply_invoice(self, title: str, description: str, provider_token: str, prices: List["Price"], *,
-                            photo_url: Optional[str] = None,
-                            need_name: Optional[bool] = False, need_phone_number: Optional[bool] = False,
-                            need_email: Optional[bool] = False,
-                            need_shipping_address: Optional[bool] = False, is_flexible: Optional[bool] = True):
+    async def reply_audio(self, audio: bytes | str | "Audio", *, caption: Optional[str] = None):
         """
-        For the documentation of the arguments, please see :meth:`bale.Bot.send_invoice`
+        For the documentation of the arguments, please see :meth:`bale.Bot.send_audio`.
         """
-        return await self.bot.send_invoice(self.chat_id, title, description, provider_token, prices,
-                                           photo_url=photo_url, need_name=need_name, need_email=need_email,
-                                           need_phone_number=need_phone_number,
-                                           need_shipping_address=need_shipping_address, is_flexible=is_flexible)
+        return await self.bot.send_video(self.chat_id, audio, caption=caption,
+                                         reply_to_message_id=self.message_id if not self.chat.type.is_group_chat() else None)
 
-    async def edit(self, text: str, *, components: "Components" | "RemoveComponents" = None) -> Message:
+    async def edit(self, text: str, *, components: "Components" | "RemoveMenuKeyboard" = None) -> Message:
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.edit_message`
         """
