@@ -27,90 +27,28 @@ import aiohttp
 from ..error import (NetworkError, TimeOut, NotFound, Forbidden, APIError, BaleError, HTTPClientError, RateLimited, HTTPException)
 from .parser import ResponseParser
 from .utils import ResponseStatusCode
-from collections import deque
 
 __all__ = ("HTTPClient", "Route")
 
-
-class RateLimit:
-	__slots__ = (
-		"_loop",
-		"_requests",
-		"_has_rate_limit"
-	)
-	def __init__(self, loop):
-		self._has_rate_limit = False
-		self._requests = deque()
-		self._loop = loop
-
-	def enable(self):
-		self._has_rate_limit = True
-
-	def _next(self):
-		while self._requests:
-			future = self._requests.popleft()
-
-			if not future.done():
-				future.set_result(None)
-				break
-
-	def _wake(self):
-		while self._requests:
-			future = self._requests.popleft()
-			if not future.done():
-				future.set_result(None)
-
-	async def new_request(self):
-		if self._has_rate_limit:
-			future = self._loop.create_future()
-			self._requests.append(future)
-
-			try:
-				await future
-			except:
-				future.cancel()
-				if not self._has_rate_limit:
-					self._next()
-				raise
-
-	async def __aenter__(self):
-		await self.new_request()
-		return self
-
-	async def __aexit__(self, exc_type, exc_val, exc_tb):
-		if len(self._requests) > 0:
-			self._next()
-		else:
-			self._has_rate_limit = False
-
-	def __bool__(self):
-		return self._has_rate_limit
-
 class Route:
 	"""Route Class for http"""
 	__slots__ = (
 		"method",
-		"path",
-		"token",
-		"_base"
+		"endpoint",
+		"token"
 	)
 
-	def __init__(self, method: str, path: str, token: str):
+	def __init__(self, method: str, endpoint: str, token: str):
 		if not isinstance(token, str):
 			raise TypeError("token param must be str.")
 		self.method = method
-		self.path = path
+		self.endpoint = endpoint
 		self.token = token
-		self._base = BALE_API_BASE_URL
 
 	@property
 	def url(self):
-		"""finally url"""
-		return self._base + "bot" + self.token + "/" + self.path
-
-	def set_base(self, _value):
-		"""Set base url for route"""
-		self._base = _value
+		"""export url for request"""
+		return "{base_url}bot{token}/{endpoint}".format(base_url = BALE_API_BASE_URL, token = self.token, endpoint = self.endpoint)
 
 class HTTPClient:
 	"""Send a Request to BALE API Server"""
@@ -118,17 +56,13 @@ class HTTPClient:
 	__slots__ = (
 		"_loop",
 		"token",
-		"__session",
-		"rate_limit",
-		"base_url"
+		"__session"
 	)
 
-	def __init__(self, loop, token=None, base_url = None):
+	def __init__(self, loop, token):
 		self.__session = None
 		self._loop: asyncio.AbstractEventLoop = loop
 		self.token = token
-		self.rate_limit = RateLimit(self.loop)
-		self.base_url: str = base_url
 
 	def is_closed(self):
 		return self.__session is None
@@ -140,7 +74,6 @@ class HTTPClient:
 	@loop.setter
 	def loop(self, _value):
 		self._loop = _value
-		self.rate_limit._loop = _value
 
 	def reload_session(self):
 		"""Reset Session"""
@@ -149,6 +82,8 @@ class HTTPClient:
 
 	async def start(self):
 		"""Start Http client"""
+		if self.__session:
+			raise RuntimeError("HTTPClient started ")
 		self.__session = aiohttp.ClientSession(loop=self.loop, connector=aiohttp.TCPConnector(keepalive_timeout=20.0))
 
 	async def close(self):
@@ -158,56 +93,49 @@ class HTTPClient:
 			self.__session = None
 
 	async def request(self, route: Route, **kwargs):
-		if self.base_url:
-			route.set_base(self.base_url)
 		url = route.url
 		method = route.method
-		async with self.rate_limit:
-			for tries in range(5):
-				try:
-					async with self.__session.request(method=method, url=url, **kwargs) as response:
-						response: aiohttp.ClientResponse = response
-						parsed_response = await ResponseParser.from_response(response)
-						if response.status == ResponseStatusCode.OK:
-							return parsed_response
-						elif response.status == ResponseStatusCode.NOT_FOUND:
-							raise NotFound(parsed_response.description)
-						elif response.status == ResponseStatusCode.PERMISSION_DENIED:
+		for tries in range(5):
+			try:
+				async with self.__session.request(method=method, url=url, **kwargs) as response:
+					response: aiohttp.ClientResponse = response
+					parsed_response = await ResponseParser.from_response(response)
+					if response.status == ResponseStatusCode.OK:
+						return parsed_response
+					elif response.status == ResponseStatusCode.NOT_FOUND:
+						raise NotFound(parsed_response.description)
+					elif response.status == ResponseStatusCode.PERMISSION_DENIED:
+						raise Forbidden()
+					elif not parsed_response.ok or response.status in (ResponseStatusCode.NOT_INCORRECT, ResponseStatusCode.RATE_LIMIT):
+						if parsed_response.description == HTTPClientError.USER_OR_CHAT_NOT_FOUND:
+							raise NotFound("User or Chat not Found")
+						elif response.status == ResponseStatusCode.RATE_LIMIT or parsed_response.description in (HTTPClientError.RATE_LIMIT, HTTPClientError.LOCAL_RATE_LIMIT):
+							if tries >= 4:
+								raise RateLimited()
+
+							await asyncio.sleep((1 + tries) * 2)
+							continue
+						elif parsed_response.description == HTTPClientError.PERMISSION_DENIED:
 							raise Forbidden()
-						elif not parsed_response.ok or response.status in (ResponseStatusCode.NOT_INCORRECT, ResponseStatusCode.RATE_LIMIT):
-							if parsed_response.description == HTTPClientError.USER_OR_CHAT_NOT_FOUND:
-								raise NotFound("User or Chat not Found")
-							elif response.status == ResponseStatusCode.RATE_LIMIT or parsed_response.description in (HTTPClientError.RATE_LIMIT, HTTPClientError.LOCAL_RATE_LIMIT):
-								if tries >= 4:
-									raise RateLimited()
 
-								if bool(self.rate_limit):
-									await self.rate_limit.new_request()
-								else:
-									self.rate_limit.enable()
-									await asyncio.sleep(tries * 2 + 1)
-								continue
-							elif parsed_response.description == HTTPClientError.PERMISSION_DENIED:
-								raise Forbidden()
-
-							raise APIError(
-									str(parsed_response.error_code), parsed_response.description
-								)
-				except aiohttp.ClientConnectorError as error:
-					raise NetworkError(str(error))
-				except aiohttp.ServerTimeoutError:
-					raise TimeOut()
-				except aiohttp.ClientOSError as error:
-					raise BaleError(str(error))
-				except Exception as error:
-					raise HTTPException(error)
+						raise APIError(
+								str(parsed_response.error_code), parsed_response.description
+							)
+			except aiohttp.ClientConnectorError as error:
+				raise NetworkError(str(error))
+			except aiohttp.ServerTimeoutError:
+				raise TimeOut()
+			except aiohttp.ClientOSError as error:
+				raise BaleError(str(error))
+			except Exception as error:
+				raise HTTPException(error)
 
 	async def get_file(self, file_id):
-		async with self.__session.get(BALE_API_FILE_URL + "/" + "bot" + self.token + "/" + file_id) as response:
+		async with self.__session.get("{base_file_url}/bot{token}/{file_id}".format(base_file_url = BALE_API_FILE_URL, token = self.token, file_id = file_id)) as response:
 			if response.status == ResponseStatusCode.OK:
 				return await response.read()
-			elif response.status == ResponseStatusCode.NOT_FOUND:
-				raise NotFound("Document is not Found")
+			elif response.status in (ResponseStatusCode.NOT_INCORRECT, ResponseStatusCode.NOT_FOUND):
+				raise NotFound("File is not Found")
 			elif response.status == ResponseStatusCode.PERMISSION_DENIED:
 				raise Forbidden()
 			else:
